@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -40,7 +40,7 @@ public:
     QString selectedProfile() const;
 
 private:
-    Ui::SelectThunderbirdProfileWidget *ui;
+    Ui::SelectThunderbirdProfileWidget *ui = nullptr;
 };
 
 class MAILIMPORTER_TESTS_EXPORT SelectThunderbirdProfileDialog : public QDialog
@@ -53,7 +53,7 @@ public:
     void fillProfile(const QMap<QString, QString> &map, const QString &defaultProfile);
 
 private:
-    SelectThunderbirdProfileWidget *mSelectProfile;
+    SelectThunderbirdProfileWidget *mSelectProfile = nullptr;
 };
 }
 
